%define         Werror_cflags      %nil
%define         crel %(echo %{version} | cut -d. -f1,2)

Summary:        The BOINC client core
Name:           boinc-client
Version:        7.16.21
Release:        %mkrel 1
License:        LGPLv2+
Group:          Sciences/Other
URL:            http://boinc.berkeley.edu/
Source0:        https://github.com/BOINC/boinc/archive/client_release/%{crel}/%{version}/%{name}_release-%{crel}-%{version}.tar.gz
Source1:        boinc-client.service
Source2:        boinc-client-tmpfiles.conf
Source3:        boinc-manager.desktop
Source4:        trim
# Wrapper to fix GPU detection (fedora)
Source5:        boinc_gpu
Source6:        boinc-client.logrotate
# Slightly modified patch from upstream

# Upstream patches:

# Mageia patches
Patch500:	boinc-client-openssl3.patch

BuildRequires:  docbook2x
BuildRequires:  gettext
BuildRequires:  wxgtk-devel
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(freeglut)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xscrnsaver)

Requires(pre):    rpm-helper >= %{rpmhelper_required_version}
Requires(post):   rpm-helper >= %{rpmhelper_required_version}
Requires(preun):  rpm-helper >= %{rpmhelper_required_version}
Requires(postun): rpm-helper >= %{rpmhelper_required_version}


%description
The Berkeley Open Infrastructure for Network Computing (BOINC) is an open-
source software platform which supports distributed computing, primarily in
the form of "volunteer" computing and "desktop Grid" computing.  It is well
suited for problems which are often described as "trivially parallel".  BOINC
is the underlying software used by projects such as SETI@home, Einstein@Home,
ClimatePrediciton.net, the World Community Grid, and many other distributed
computing projects.
This package installs the BOINC client software, which will allow your
computer to participate in one or more BOINC projects, using your spare
computer time to search for cures for diseases, model protein folding, study
global warming, discover sources of gravitational waves, and many other types
of scientific and mathematical research.

%package -n boinc-manager
Summary:        GUI to control and monitor %{name}
Group:          Sciences/Other
Requires:       %{name} = %{version}-%{release}

%description -n boinc-manager
The BOINC Manager is a graphical monitor and control utility for the BOINC
core client. It gives a detailed overview of the state of the client it is
monitoring. The BOINC Manager has two modes of operation, the "Simple View" in
which it only displays the most important information and the "Advanced View"
in which all information and all control elements are available.

%package devel
Summary:        Development files for %{name}
Group:          Development/Other
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig(openssl)
Requires:       mysql-devel

%description devel
This package contains development files for %{name}.

%package static
Summary:        Static libraries for %{name}
Group:          Sciences/Other
Requires:       %{name}-devel = %{version}-%{release}

%description static
This package contains static libraries for %{name}.


%prep
%setup -q -n %{name}_release-%{crel}-%{version}
%autopatch -p1

# Fix encoding
for file in $(ls | grep checkin_notes_20); do
    iconv -f ISO-8859-1 -t UTF-8 -o ${file}.utf8 ${file}
    mv ${file}.utf8 ${file}
done

# Fix file permissions
for file in $(ls clientgui | grep .cpp$ ) $(ls clientgui | grep .h$ ); do 
    chmod 644 clientgui/${file}
done

# Since http://git.savannah.gnu.org/cgit/autoconf.git/commit/?id=ec90049dfcf4538750e61d675d885157fa5ca7f8
# AC_CHECK_DECLS call with CXXFLAGS=-mavx fails in arm
%ifarch %{arm} aarch64
sed -i -e 's/\s\?-mavx//g' configure.ac
%endif

%build
export CXXFLAGS="%{build_cxxflags} -Wno-deprecated-declarations"

#squidf: add x86_64 platform for consistency, at least
%ifarch x86_64
%global boinc_platform x86_64-pc-linux-gnu
%endif
%ifarch %{ix86}
%global boinc_platform i686-pc-linux-gnu
%endif
%ifarch powerpc ppc
%global boinc_platform powerpc-linux-gnu
%endif
%ifarch powerpc64 ppc64
%global boinc_platform ppc64-linux-gnu
%endif
%ifarch aarch64
%global boinc_platform aarch64-unknown-linux-gnu
%endif

./_autosetup -f

%configure  \
                --disable-silent-rules \
                --disable-fcgi \
                --disable-shared \
                --disable-server \
                --enable-client \
                --enable-manager \
                --enable-unicode \
                --enable-dynamic-client-linkage \
                --with-ssl \
                --with-x \
                --with-boinc-platform=%{boinc_platform} \
                STRIP=:

# Disable rpaths
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make_build

%install
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/16x16/apps
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/32x32/apps
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/48x48/apps
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_localstatedir}/lib/boinc
mkdir -p %{buildroot}%{_mandir}/man1
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d/
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
%make_install


# Set up links to correct log locations
#ln -s /var/log/boinc/ %%{_localstatedir}/log/boinc.log 
#ln -s /var/log/boinc/ %%{_localstatedir}/log/boincerr.log 

# Remove libtool archives
find %{buildroot} -name '*.la' -delete

# Use custom systemd script and logrotate configuration file
rm -f %{buildroot}%{_sysconfdir}/init.d/%{name} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__install} -p -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
%{__install} -D -p -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf
%{__install} -D -p -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -p -m 0755 %{SOURCE5} %{buildroot}%{_bindir}

# Install Icons
install -p -m644  packages/generic/sea/boincmgr.16x16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/boincmgr.png
install -p -m644 packages/generic/sea/boincmgr.32x32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/boincmgr.png
install -p -m644 packages/generic/sea/boincmgr.48x48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/boincmgr.png

desktop-file-install %{?_remove_encoding} \
  --dir %{buildroot}%{_datadir}/applications \
  %{SOURCE3}

%find_lang BOINC-Manager
%find_lang BOINC-Client

# bash-completion
install -p -m644 client/scripts/boinc.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}

%pre
%_pre_useradd boinc /dev/null /bin/false


%post
%_tmpfilescreate %{name}
%_post_service %{name}


%preun
%_preun_service %{name}

%postun
%_postun_userdel boinc



%files -f BOINC-Client.lang
%doc COPYING COPYRIGHT checkin_notes checkin_notes_*
%{_bindir}/boinc
%{_bindir}/boinc_client
%{_bindir}/boinccmd
%{_bindir}/boinc_gpu
%{_bindir}/switcher
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf

%{_mandir}/man?/boinccmd.?.*
%{_mandir}/man?/boinc.?.*
%attr(-,boinc,boinc) %{_localstatedir}/lib/boinc/
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_datadir}/bash-completion/completions/boinc-client


%files -n boinc-manager -f BOINC-Manager.lang
%{_bindir}/boincmgr
%{_bindir}/boincscr
%{_datadir}/applications/boinc-manager.desktop
%{_iconsdir}/*/*/apps/boincmgr.*
%{_mandir}/man?/boincmgr.?.*

%files static
%{_libdir}/libboinc.a
%{_libdir}/libboinc_api.a
%{_libdir}/libboinc_crypt.a
%{_libdir}/libboinc_graphics2.a
%{_libdir}/libboinc_opencl.a

%files devel
%{_includedir}/boinc


%changelog
* Mon Jul 18 2022 squidf <squidf> 7.16.21-1.mga8
+ Revision: 1869360
- Update to 7.16.21 (mga#30648)
- Set x86_64 boinc platform
- Consistent working folder path between desktop file and systemd service
- Adjust source name to point to release versions
- Add boinc-client-openssl3 patch
+ wally <wally>
- rebuild for wxgtk 3.1.5 (mga#29848)

* Fri Jan 01 2021 wally <wally> 7.16.14-2.mga8
+ Revision: 1667690
- rebuild for wxgtk pre 3.1.5 snapshot

* Sat Dec 26 2020 wally <wally> 7.16.14-1.mga8
+ Revision: 1663969
- new version 7.16.14
- force recreation of autoconf files

* Tue Nov 17 2020 daviddavid <daviddavid> 7.16.12-1.mga8
+ Revision: 1646915
- new version: 7.16.12

* Tue Sep 01 2020 daviddavid <daviddavid> 7.16.11-1.mga8
+ Revision: 1620566
- new version: 7.16.11

* Sat Aug 29 2020 daviddavid <daviddavid> 7.16.10-1.mga8
+ Revision: 1619495
- new version: 7.16.10

* Wed Aug 19 2020 daviddavid <daviddavid> 7.16.8-1.mga8
+ Revision: 1615614
- new version: 7.16.8

* Sun Aug 16 2020 wally <wally> 7.16.7-2.mga8
+ Revision: 1614328
- rebuild for new wxgtk 3.1.4

* Mon Jun 01 2020 daviddavid <daviddavid> 7.16.7-1.mga8
+ Revision: 1589372
- new version: 7.16.7

* Wed Apr 22 2020 daviddavid <daviddavid> 7.16.6-1.mga8
+ Revision: 1570621
- new version: 7.16.6

* Sun Mar 22 2020 kekepower <kekepower> 7.16.5-1.mga8
+ Revision: 1559019
- Update to version 7.16.5

* Wed Feb 19 2020 umeabot <umeabot> 7.16.4-2.mga8
+ Revision: 1544201
- Mageia 8 Mass Rebuild

* Fri Jan 24 2020 daviddavid <daviddavid> 7.16.4-1.mga8
+ Revision: 1482726
- new version: 7.16.4
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Nov 12 2019 wally <wally> 7.16.3-2.mga8
+ Revision: 1459454
- rebuild for wxgtk 3.1.3

* Mon Sep 30 2019 daviddavid <daviddavid> 7.16.3-1.mga8
+ Revision: 1448370
- new version: 7.16.3

* Thu Aug 01 2019 daviddavid <daviddavid> 7.16.1-1.mga8
+ Revision: 1426664
- new version: 7.16.1
- remove merged upstream patches
+ wally <wally>
- add upstream patch to fix jumping tasklist

* Thu Jul 18 2019 wally <wally> 7.14.2-4.mga8
+ Revision: 1422400
- add a slightly modified patch from upstream to fix build with gtk3 enabled wxgtk 3.1.2

* Sat Mar 16 2019 wally <wally> 7.14.2-3.mga7
+ Revision: 1377885
- build using same gtk version as wxgtk uses (mga#24520)

* Tue Feb 26 2019 wally <wally> 7.14.2-2.mga7
+ Revision: 1370256
- rebuild with wxgtk without webkit1 support

* Thu Oct 11 2018 daviddavid <daviddavid> 7.14.2-1.mga7
+ Revision: 1319575
- new version: 7.14.2

* Wed Oct 03 2018 daviddavid <daviddavid> 7.14.1-1.mga7
+ Revision: 1317230
- new version: 7.14.1

* Sun Sep 30 2018 daviddavid <daviddavid> 7.14.0-1.mga7
+ Revision: 1312623
- new version: 7.14.0

* Fri Sep 21 2018 umeabot <umeabot> 7.9.3-2.mga7
+ Revision: 1295587
- Mageia 7 Mass Rebuild

* Fri Mar 23 2018 kekepower <kekepower> 7.9.3-1.mga7
+ Revision: 1211615
- Update to version 7.9.3
+ josh <josh>
- Consolidate location for bash-completion scripts
+ tv <tv>
- build with compat-openssl10-devel
- new release

* Sat Jun 03 2017 akien <akien> 7.2.42-10.mga6
+ Revision: 1106086
- Rebuild for wxgtk 3.0.3.1

* Wed Mar 02 2016 umeabot <umeabot> 7.2.42-9.mga6
+ Revision: 983169
- Rebuild for openssl

* Sat Feb 13 2016 umeabot <umeabot> 7.2.42-8.mga6
+ Revision: 959622
- Mageia 6 Mass Rebuild

* Sat Sep 26 2015 daviddavid <daviddavid> 7.2.42-7.mga6
+ Revision: 883800
- rebuild with gcc 5.2.1

* Sat Aug 01 2015 shlomif <shlomif> 7.2.42-6.mga6
+ Revision: 860424
- Fix MGA#16293 (patch by ysoft) - .service had exec bit set.

* Wed Nov 05 2014 eatdirt <eatdirt> 7.2.42-5.mga5
+ Revision: 795667
- Fix desktop file and logrotate

* Tue Nov 04 2014 eatdirt <eatdirt> 7.2.42-4.mga5
+ Revision: 795430
- Migrating boinc-client service to systemd (mga#12129)

* Wed Oct 15 2014 umeabot <umeabot> 7.2.42-3.mga5
+ Revision: 748312
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 7.2.42-2.mga5
+ Revision: 678193
- Mageia 5 Mass Rebuild

* Mon Mar 24 2014 dams <dams> 7.2.42-1.mga5
+ Revision: 607961
- new version 7.2.42

* Fri Feb 28 2014 dams <dams> 7.2.39-1.mga5
+ Revision: 597734
- new stable version 7.2.39
- replace init.d with systemd

* Fri Oct 18 2013 umeabot <umeabot> 7.0.36-3.mga4
+ Revision: 503138
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 7.0.36-2.mga3
+ Revision: 346941
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 08 2012 dams <dams> 7.0.36-1.mga3
+ Revision: 303624
- new version 7.0.36

* Sun Aug 12 2012 dams <dams> 7.0.33-1.mga3
+ Revision: 280880
- add back the icon (in Hi-Res) for the .desktop
- new version 7.0.33
- clean specfile
- remove useless single build
- rediff patch

* Mon Aug 06 2012 shlomif <shlomif> 7.0.28-1.mga3
+ Revision: 279358
- New version 7.0.28

* Fri Dec 30 2011 supp <supp> 7.0.6-1.mga2
+ Revision: 188895
- update to 7.0.6 release

* Mon Sep 26 2011 fwang <fwang> 6.12.38-1.mga2
+ Revision: 147978
- update filelist
- disable screensaver build
- fix build with latest libnotify
- fix clientgui building
- enable manager
- add more br
- new version 6.12.38

* Fri Sep 23 2011 fwang <fwang> 6.10.58-3.mga2
+ Revision: 147014
- fix group
- br xmu
- br freeglut
- clean br
- disable static
+ ahmad <ahmad>
- Rebuild against wxgtk2.8 with enabled catch_segvs
- Build with wxgtku-devel for unicode support
+ stormi <stormi>
- remove unused sources

* Thu Jun 09 2011 dams <dams> 6.10.58-1.mga2
+ Revision: 102485
- update to 6.10.58 and rediff patchs
- imported package boinc-client


* Thu Jun 09 2011 dams <dams> 6.10.58-1.mga2
+ Revision: 102485
- update to 6.10.58 and rediff patchs
- imported package boinc-client


* Fri Mar 19 2010 Tomas Kindl <supp@mandriva.org> 6.10.17-1mdv2010.1
+ Revision: 525287
- fix underlinking issue
- fix missing BuildRequires
- fix manpages generation
- Now really drop that patch...
- bump to 6.10.17 release
- frop gcc4.4 patch as it's no longer needed

  + Thomas Backlund <tmb@mandriva.org>
    - fix typo in initscript

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Emmanuel Andry <eandry@mandriva.org>
    - New version 6.6.37
    - use fedora spec and patches

* Sat Feb 28 2009 Guillaume Rousse <guillomovitch@mandriva.org> 6.6.1-1.svn20081217.2mdv2009.1
+ Revision: 345952
- rebuild

* Tue Feb 10 2009 Zombie Ryushu <ryushu@mandriva.org> 6.6.1-1.svn20081217.1mdv2009.1
+ Revision: 339118
- Upgrade to 6.6.1
- Upgrade to 6.6.1
- New Version 6.4.5
- New Version 6.4.5

* Sun Jun 15 2008 Funda Wang <fwang@mandriva.org> 5.10.45-1.svn20080315.1mdv2009.0
+ Revision: 219256
- BR unicode version of wxgtk2.8
- fix version
- disable server
- add missing files
- covert to mandriva style
- import boinc-client


* Sat May 17 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.45-14.20080315svn
- Fixed opening locales by adding boinc-locales.patch

* Sat May 17 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.45-13.20080315svn
- Fixed boincmgr segfaulting on F9/x86_64 (#445902) by adding
  boinc-parsecolor.patch (Patch2).

* Mon May 12 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.45-12.20080315svn
- Do not ship ca-bundle.crt as it is already included in curl.
- Fixed the almost empty debuginfo package (do not strip anything).
- Patches documented according to the guidelines (PatchUpstreamStatus)

* Sun May 04 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.45-11.20080315svn
- Fixed find command because starting with findutils-4.4.0-1.fc10, find 
  returns a non-zero value when "-delete" fails.
  (for more details on this see bug #20802 on savannah.gnu.org)

* Sat May 03 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.45-10.20080315svn
- Fixed handling stale lockfiles (#444936).
- Initscript fixed to be compliant with current SysVInit guidelines
  (added condrestart, try-restart, force-reload actions).

* Wed Apr 23 2008 Lubomir Kundrak <lkundrak@redhat.com> - 5.10.45-9.20080315svn
- Do not expect chown of nonexistent files to succeed (#443568)

* Mon Apr 14 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.45-8.20080315svn
- Fixed projects permissions (calling chown recursively).

* Mon Apr 14 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.45-7.20080315svn
- Fixed running the boinc daemon as boinc user instead of root, file
  permissions changed accordingly.

* Mon Apr 07 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.45-6.20080315svn
- Using --with-boinc-platform=i686-pc-linux-gnu on i386 instead of --build,
  --host, --target
- Added bash completion script.

* Fri Apr 04 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.45-5.20080315svn
- Fixed build on i386 since it needs to be configured as i686-pc-linux-gnu 
  and not i386-pc-linux-gnu.

* Mon Mar 24 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.45-4.20080315svn
- Removed unnecessary slash before the {_localstatedir} macro.

* Sun Mar 23 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.45-3.20080315svn
- Logs moved to /var/log so that all SELinux related things could be removed.
- The error.log file has been renamed to boincerr.log.

* Sun Mar 16 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.45-2.20080315svn
- Fixed typo in the semanage command (missing boinc subdirectory and quotes).
- Fixed installing empty log files.
- Fixed Patch1 (has been created before propagating the flags using the
  _autosetup script).

* Sat Mar 15 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.45-1.20080315svn
- Updated to 5.10.45
- Added Patch1 removing -fomit-frame-pointer and -ffast-math compiler flags.
- Updated Patch0 (/lib/boinc_cmd.C changes have been merged in upstream).
- Log files (/var/lib/{boinc,error}.log) are touched during the installation
  so that correct(?) SELinux context can be set on them.
- Added Requires(post, postun): policycoreutils because of previous point.

* Sat Mar 08 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.40-8.20080206svn
- Added missing Requires: mysql-devel for the -devel subpackage

* Fri Mar 07 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.40-7.20080206svn
- Removed unnecessary client stopping when upgrading.
- Removed unnecessary ldconfig calls.
- A few changes unifying macros usage.
- Fixed missing directory ownership of {_localstatedir}/lib/boinc
- Added missing Requires: openssl-devel for the -devel subpackage

* Wed Feb 27 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.40-6.20080206svn
- Added patch making the sources compatible with GCC4.3

* Mon Feb 25 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.40-5.20080206svn
- Added the "stripchart" source directory to be trimmed.
- Removed all translations (will be added later through l10n specspo module).
- Fixed logrotate in case that boinc won't be running at the logrotate time.
- Changed summary and description according to upstream's choice.
- Fixed wrong SELinux context on error.log and boinc.log.
- Removed .svn directories from the source.
- Fixed missing Short-Description field in the init script.
- Service disabled by default.
- Fixed missing reload action in the init script.
- Changed the way of using the subsys directory for locking so that 
  rpmlint doesn't complain.
- Added script converting non-unicode files into UTF8.
- Added script removing execution rights on documentation files.
- Added documentation: checkin_notes_2007
- Init script behaves polite now when starting/stopping the service which
  has been already started/stopped (i.e. exits with 0).

* Fri Feb 16 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.40-4.20080206svn
- Fixed locales installation path
- Fixed missing Provides: boinc-client-static in the -devel subpackage

* Thu Feb 14 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.40-3.20080206svn
- Fixed the init script (now using the daemon function properly)
- Fixed missing chkconfig setup
- Added Requires: chkconfig

* Tue Feb 12 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.40-2.20080206svn
- Fixed missing boinc user and group

* Tue Feb 06 2008 Milos Jakubicek <xjakub@fi.muni.cz> - 5.10.40-1.20080206svn
- Updated to 5.10.40.
- Fixed unpackaged files: libboinc_graphics*.
- Fixed missing BuildRequires: mysql-devel, libXmu-devel, libjpeg-devel.
- Added locales.
- Added script trimming binaries and other unnecessary code from the source.
- Added ldconfig call for the -devel subpackage.
- Added Czech and German translation.

* Wed Jan 09 2008 Debarshi Ray <rishi@fedoraproject.org> - 5.10.32-1.20080109svn
- Initial build. Imported SPEC written by Eric Myers and Milos Jakubicek.
- Disabled parallel make to prevent failure with -j3.
